==> dde-file-manager_5.2.18.orig.tar.xz: dde-file-manager-5.2.18/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="ug" version="2.1">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>دەلىللەش ۋاقتى ئۆتۈپ كەتتى</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>دىسكا ھۆججىتى ئىگىلىۋېلىندى ، ئۆچۈرگىلى بولمايدۇ</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>دىسكا ئالدىراش ، ھازىر چىقىرىۋېتەلمەيدۇ</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>دىسكا ئالدىراش ، ھازىر چىقىرىۋېتەلمەيدۇ</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>دىسكا ئالدىراش ، ھازىر بىخەتەر چىقىرىۋېتەلمەيدۇ</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 رايۇن</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>نامەلۇم</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>ھۆججەت باشقۇرغۇچ</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>ئۈسكۈنە نورمال ئۆچۈرۈلمىدى</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>«بىخەتەر ئۆچۈرۈش» نى باسقاندىن كېيىن ئۇلىنىشنى ئۈزۈڭ</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation type="vanished">دىسكا ئالدىراش ، ھازىر چىقىرىۋېتەلمەيدۇ</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation type="vanished">دىسكا ئالدىراش ، ھازىر بىخەتەر چىقىرىۋېتەلمەيدۇ</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>ئۈسكۈنىنى چىقىرالمىدى</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>دىسكىغا “%1” ئىشلەتكۈچى ئاغدۇرۇلغان، ئۆچۈرۈش ھوقۇقىڭىز يوق.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>ماس ئاغدۇرۇش ئۈسكۈنىسى تېپىلمىدى</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>دىسكا</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>دىسكا</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>ئېچىش</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>ھەممىسىنى چىقىرىش</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>ئۈسكۈنە بىخەتەر ئۆچۈرۈلدى</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>ئوقۇغىلى، يازغىلى بولمايدۇ</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>بۇ ھۆججەتنى ئوقۇش ھوقۇقىڭىز يوق</translation>
    </message>
    <message>
        <source>Confirm</source>
        <translation>جەزملەشتۈرۈش</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>ئۈسكۈنە سايىلىنىۋاتىدۇ، سايىلەشنى توختىتامسىز؟</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Stop</source>
        <translation>توختىتىمەن</translation>
    </message>
</context>
</TS>

==> dde-file-manager_5.8.1.orig.tar.xz: dde-file-manager-5.8.1/src/dde-dock-plugins/disk-mount/translations/dde-disk-mount-plugin_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
<context>
    <name>DUMountManager</name>
    <message>
        <source>Authentication timed out</source>
        <translation>دەلىللەش ۋاقتى ئۆتۈپ كەتتى</translation>
    </message>
    <message>
        <source>Disk is busy, cannot unmount now</source>
        <translation>دىسكا ھۆججىتى ئىگىلىۋېلىندى ، ئۆچۈرگىلى بولمايدۇ</translation>
    </message>
    <message>
        <source>Disk is busy, cannot eject now</source>
        <translation>دىسكا ئالدىراش ، ھازىر چىقىرىۋېتەلمەيدۇ</translation>
    </message>
    <message>
        <source>The device is busy, cannot eject now</source>
        <translation>دىسكا ئالدىراش ، ھازىر چىقىرىۋېتەلمەيدۇ</translation>
    </message>
    <message>
        <source>The device is busy, cannot remove now</source>
        <translation>دىسكا ئالدىراش ، ھازىر بىخەتەر چىقىرىۋېتەلمەيدۇ</translation>
    </message>
</context>
<context>
    <name>DeepinStorage</name>
    <message>
        <source>%1 Volume</source>
        <translation>%1 رايۇن</translation>
    </message>
</context>
<context>
    <name>DiskControlItem</name>
    <message>
        <source>Unknown</source>
        <translation>نامەلۇم</translation>
    </message>
</context>
<context>
    <name>DiskControlWidget</name>
    <message>
        <source>dde-file-manager</source>
        <translation>ھۆججەت باشقۇرغۇچ</translation>
    </message>
    <message>
        <source>The device was not safely removed</source>
        <translation>ئۈسكۈنە نورمال ئۆچۈرۈلمىدى</translation>
    </message>
    <message>
        <source>Click &quot;Safely Remove&quot; and then disconnect it next time</source>
        <translation>«بىخەتەر ئۆچۈرۈش» نى باسقاندىن كېيىن ئۇلىنىشنى ئۈزۈڭ</translation>
    </message>
    <message>
        <source>Cannot unmount the device</source>
        <translation>ئۈسكۈنىنى چىقىرالمىدى</translation>
    </message>
    <message>
        <source>The disk is mounted by user &quot;%1&quot;, you cannot unmount it.</source>
        <translation>دىسكىغا “%1” ئىشلەتكۈچى ئاغدۇرۇلغان، ئۆچۈرۈش ھوقۇقىڭىز يوق.</translation>
    </message>
    <message>
        <source>Cannot find the mounted device</source>
        <translation>ماس ئاغدۇرۇش ئۈسكۈنىسى تېپىلمىدى</translation>
    </message>
    <message>
        <source>Disks</source>
        <translation>دىسكا</translation>
    </message>
</context>
<context>
    <name>DiskMountPlugin</name>
    <message>
        <source>Disk</source>
        <translation>دىسكا</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>ئېچىش</translation>
    </message>
    <message>
        <source>Eject all</source>
        <translation>ھەممىسىنى چىقىرىش</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>The device has been safely removed</source>
        <translation>ئۈسكۈنە بىخەتەر ئۆچۈرۈلدى</translation>
    </message>
    <message>
        <source>Access denied</source>
        <translation>ئوقۇغىلى، يازغىلى بولمايدۇ</translation>
    </message>
    <message>
        <source>You do not have permission to access this folder</source>
        <translation>بۇ ھۆججەتنى ئوقۇش ھوقۇقىڭىز يوق</translation>
    </message>
    <message>
        <source>Scanning the device, stop it?</source>
        <translation>ئۈسكۈنە سايىلىنىۋاتىدۇ، سايىلەشنى توختىتامسىز؟</translation>
    </message>
    <message>
        <source>Confirm</source>
        <comment>button</comment>
        <translation>جەزملەشتۈرۈش</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Stop</source>
        <comment>button</comment>
        <translation>توختىتىمەن</translation>
    </message>
</context>
</TS>
